let android = false
let libev_default = true
let _HAVE_LIBEV = true
let _HAVE_PTHREAD = true
let _HAVE_EVENTFD = true
let _HAVE_FD_PASSING = true
let _HAVE_GETCPU = true
let _HAVE_AFFINITY = true
let _HAVE_GET_CREDENTIALS_LINUX = true
let _HAVE_GET_CREDENTIALS_NETBSD = false
let _HAVE_GET_CREDENTIALS_OPENBSD = false
let _HAVE_GET_CREDENTIALS_FREEBSD = false
let _HAVE_GETPEEREID = false
let _HAVE_FDATASYNC = true
let _HAVE_NETDB_REENTRANT = true
let _HAVE_REENTRANT_HOSTENT = true
let _HAVE_ST_MTIM_TV_NSEC = true
let _HAVE_ST_MTIMESPEC_TV_NSEC = false
let _HAVE_ST_MTIMENSEC = false
let _HAVE_BSD_MINCORE = false
let _HAVE_ACCEPT4 = true
